@@ -14,6 +14,8 @@ app.command()(mod.main)
 def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
+    assert "Arguments:" in result.output
+    assert "NAME  [required]" in result.output
     assert "--lastname TEXT" in result.output
     assert "--formal / --no-formal" in result.output
 
