@@ -21,7 +21,7 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "--fullname TEXT" in result.output
-    assert "[default: Wade Wilson]" in result.output
+    assert "[default: Wade Wilson]" not in result.output
 
 
 def test_script():
