@@ -33,7 +33,7 @@ def test_invalid():
     result = runner.invoke(app, ["Camila", "--age", "15.3"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "--age": 15.3 is not a valid integer' in result.output
+        "Error: Invalid value for '--age': 15.3 is not a valid integer" in result.output
     )
 
 
