@@ -18,7 +18,7 @@ def test_not_exists(tmpdir):
         config_file.unlink()
     result = runner.invoke(app, ["--config", f"{config_file}"])
     assert result.exit_code != 0
-    assert 'Error: Invalid value for "--config": File' in result.output
+    assert "Error: Invalid value for '--config': File" in result.output
     assert "does not exist" in result.output
 
 
@@ -35,7 +35,7 @@ def test_dir():
     result = runner.invoke(app, ["--config", "./"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "--config": File "./" is a directory.'
+        "Error: Invalid value for '--config': File './' is a directory."
         in result.output
     )
 
