@@ -9,6 +9,7 @@ from uuid import UUID
 import click
 
 from .completion import get_completion_inspect_parameters
+from .core import TyperArgument, TyperCommand
 from .models import (
     AnyType,
     ArgumentInfo,
@@ -23,9 +24,11 @@ from .models import (
     NoneType,
     OptionInfo,
     ParameterInfo,
+    ParamMeta,
     Required,
     TyperInfo,
 )
+from .utils import get_params_from_function
 
 
 def get_install_completion_arguments() -> Tuple[click.Parameter, click.Parameter]:
@@ -140,7 +143,7 @@ class Typer:
         deprecated: bool = False,
     ) -> Callable[[CommandFunctionType], CommandFunctionType]:
         if cls is None:
-            cls = click.Command
+            cls = TyperCommand
 
         def decorator(f: CommandFunctionType) -> CommandFunctionType:
             self.registered_commands.append(
@@ -207,8 +210,8 @@ class Typer:
             )
         )
 
-    def __call__(self) -> Any:
-        return get_command(self)()
+    def __call__(self, *args: Any, **kwargs: Any) -> Any:
+        return get_command(self)(*args, **kwargs)
 
 
 def get_group(typer_instance: Typer) -> click.Command:
@@ -393,8 +396,8 @@ def get_params_convertors_ctx_param_name_from_function(
     convertors = {}
     context_param_name = None
     if callback:
-        signature = inspect.signature(callback)
-        for param_name, param in signature.parameters.items():
+        parameters = get_params_from_function(callback)
+        for param_name, param in parameters.items():
             if lenient_issubclass(param.annotation, click.Context):
                 context_param_name = param_name
                 continue
@@ -418,7 +421,7 @@ def get_command_from_info(command_info: CommandInfo) -> click.Command:
         convertors,
         context_param_name,
     ) = get_params_convertors_ctx_param_name_from_function(command_info.callback)
-    cls = command_info.cls or click.Command
+    cls = command_info.cls or TyperCommand
     command = cls(  # type: ignore
         name=name,
         context_settings=command_info.context_settings,
@@ -476,9 +479,9 @@ def get_callback(
 ) -> Optional[Callable]:
     if not callback:
         return None
-    signature = inspect.signature(callback)
+    parameters = get_params_from_function(callback)
     use_params: Dict[str, Any] = {}
-    for param_name, param_sig in signature.parameters.items():
+    for param_name in parameters:
         use_params[param_name] = None
     for param in params:
         use_params[param.name] = param.default
@@ -591,7 +594,7 @@ def lenient_issubclass(
 
 
 def get_click_param(
-    param: inspect.Parameter,
+    param: ParamMeta,
 ) -> Tuple[Union[click.Argument, click.Option], Any]:
     # First, find out what will be:
     # * ParamInfo (ArgumentInfo or OptionInfo)
@@ -683,7 +686,7 @@ def get_click_param(
             click.Option(
                 # Option
                 param_decls=param_decls,
-                show_default=parameter_info.show_default,
+                show_default=parameter_info.show_default,  # type: ignore
                 prompt=parameter_info.prompt,
                 confirmation_prompt=parameter_info.confirmation_prompt,
                 hide_input=parameter_info.hide_input,
@@ -717,12 +720,18 @@ def get_click_param(
         if is_list:
             nargs = -1
         return (
-            click.Argument(
+            TyperArgument(
                 # Argument
                 param_decls=param_decls,
                 type=parameter_type,
                 required=required,
                 nargs=nargs,
+                # TyperArgument
+                show_default=parameter_info.show_default,
+                show_choices=parameter_info.show_choices,
+                show_envvar=parameter_info.show_envvar,
+                help=parameter_info.help,
+                hidden=parameter_info.hidden,
                 # Parameter
                 default=default_value,
                 callback=get_param_callback(
@@ -744,12 +753,12 @@ def get_param_callback(
 ) -> Optional[Callable]:
     if not callback:
         return None
-    signature = inspect.signature(callback)
+    parameters = get_params_from_function(callback)
     ctx_name = None
     click_param_name = None
     value_name = None
     untyped_names: List[str] = []
-    for param_name, param_sig in signature.parameters.items():
+    for param_name, param_sig in parameters.items():
         if lenient_issubclass(param_sig.annotation, click.Context):
             ctx_name = param_name
         elif lenient_issubclass(param_sig.annotation, click.Parameter):
@@ -792,11 +801,11 @@ def get_param_callback(
 def get_param_completion(callback: Optional[Callable] = None) -> Optional[Callable]:
     if not callback:
         return None
-    signature = inspect.signature(callback)
+    parameters = get_params_from_function(callback)
     ctx_name = None
     args_name = None
     incomplete_name = None
-    unassigned_params = [param for param in signature.parameters.values()]
+    unassigned_params = [param for param in parameters.values()]
     for param_sig in unassigned_params[:]:
         origin = getattr(param_sig.annotation, "__origin__", None)
         if lenient_issubclass(param_sig.annotation, click.Context):
